<?php

namespace Litecms\League\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\League\Models\League;

class LeaguePolicy
{

    /**
     * Determine if the given user can view the league.
     *
     * @param UserPolicy $user
     * @param League $league
     *
     * @return bool
     */
    public function view(UserPolicy $user, League $league)
    {
        if ($user->canDo('league.league.view') && $user->isAdmin()) {
            return true;
        }

        return $league->user_id == user_id() && $league->user_type == user_type();
    }

    /**
     * Determine if the given user can create a league.
     *
     * @param UserPolicy $user
     * @param League $league
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('league.league.create');
    }

    /**
     * Determine if the given user can update the given league.
     *
     * @param UserPolicy $user
     * @param League $league
     *
     * @return bool
     */
    public function update(UserPolicy $user, League $league)
    {
        if ($user->canDo('league.league.edit') && $user->isAdmin()) {
            return true;
        }

        return $league->user_id == user_id() && $league->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given league.
     *
     * @param UserPolicy $user
     * @param League $league
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, League $league)
    {
        return $league->user_id == user_id() && $league->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given league.
     *
     * @param UserPolicy $user
     * @param League $league
     *
     * @return bool
     */
    public function verify(UserPolicy $user, League $league)
    {
        if ($user->canDo('league.league.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given league.
     *
     * @param UserPolicy $user
     * @param League $league
     *
     * @return bool
     */
    public function approve(UserPolicy $user, League $league)
    {
        if ($user->canDo('league.league.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
